//
// SKTBezierPath.h
// By mkino
//

#import <Cocoa/Cocoa.h>
#import "SKTGraphic.h"

@interface SKTBezierPath : SKTGraphic {
    @private
    NSMutableArray*		_points;
    BOOL				_isPathClosed;
    
    NSPoint				_lastControlPoint;
    NSAffineTransform*	_transform;
    BOOL				_isFlippedVertically;
    BOOL				_isFlippedHorizontally;
    int					_selectedPointIndex;
}

//
// Accessors
//

- (void)setPoints:(NSArray*)points;
- (NSArray*)points;
- (void)setPathClosed:(BOOL)isPathClosed;
- (BOOL)isPathClosed;
- (void)setTransform:(NSAffineTransform*)transform;
- (NSAffineTransform*)transform;

//
// Anchor points and control points management
//

- (int)numberOfAnchorPoint;
- (int)indexOfPoint:(NSPoint)point;
- (int)indexOfLastAnchorPoint;
- (NSPoint)pointAtIndex:(int)index;
- (void)appendFirstAnchorPoint:(NSPoint)point;
- (void)appendAnchorPoint:(NSPoint)point controlPoint1:(NSPoint)control1 controlPoint2:(NSPoint)control2;
- (void)movePointAtIndex:(int)index toPoint:(NSPoint)point;
- (void)movePointAtIndex:(int)index bySize:(NSSize)size;
- (void)removeAnchorPointAtIndex:(int)index;

- (BOOL)isAnchorPoint:(int)index;

//
// Drawing
//

- (NSBezierPath*)origBezierPath;
- (void)drawAnchorHandlesInView:(SKTGraphicView*)view;
- (void)drawControlHandlesInView:(SKTGraphicView*)view;
- (void)drawControlHandlesFromAnchorPoint:(NSPoint)anchorPoint toControlPoint:(NSPoint)controlPoint inView:(SKTGraphicView*)view;

//
// bezierPath specific
//

- (int)pointUnderPoint:(NSPoint)point;
- (void)applyTransform;

@end
